#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-bignum-orphans
version:              0.1.1
visibility:           public
id:                   ghc-bignum-orphans-0.1.1-2hB1tM9f2XcKXEvXSkYTWe
key:                  ghc-bignum-orphans-0.1.1-2hB1tM9f2XcKXEvXSkYTWe
license:              BSD-3-Clause
copyright:            (C) 2021 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
homepage:             https://github.com/haskell-compat/ghc-bignum-orphans
synopsis:             Backwards-compatible orphan instances for ghc-bignum
description:
    @ghc-bignum-orphans@ defines orphan instances that mimic
    instances available in later versions of @ghc-bignum@ to a
    wider (older) range of compilers. @ghc-bignum-orphans@ does
    not export anything except the orphan instances themselves.

category:             Compatibility
abi:                  d84e31d689672fc682d9b6bd6f04d326
exposed:              True
exposed-modules:      GHC.Num.Orphans
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghc-bignum-orphans-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghc-bignum-orphans-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghc-bignum-orphans-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-bignum-orphans
hs-libraries:         HSghc-bignum-orphans-0.1.1-2hB1tM9f2XcKXEvXSkYTWe
depends:              base-4.18.2.1 ghc-bignum-1.3
haddock-interfaces:
    /usr/share/doc/haskell-ghc-bignum-orphans/html/ghc-bignum-orphans.haddock

haddock-html:         /usr/share/doc/haskell-ghc-bignum-orphans/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

